@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_CONF_H
-#define __PAROLE_CONF_H
+#ifndef SRC_PAROLE_CONF_H_
+#define SRC_PAROLE_CONF_H_
 
 #include <glib-object.h>
 
@@ -43,16 +43,16 @@ ParoleConf              *parole_conf_new                (void);
 
 gboolean                 parole_conf_get_property_bool  (ParoleConf *conf,
                                                          const gchar *name);
-                                                         
+
 gchar                  **parole_conf_read_entry_list    (ParoleConf *conf,
                                                          const gchar *name);
-                                                         
-void                     parole_conf_write_entry_list   (ParoleConf *conf, 
+
+void                     parole_conf_write_entry_list   (ParoleConf *conf,
                                                          const gchar *name,
-                                                         gchar **value);                                 
-                     
+                                                         gchar **value);
+
 void                     parole_conf_xfconf_init_failed (void);
 
 G_END_DECLS;
 
-#endif /* __PAROLE_CONF_H */
+#endif /* SRC_PAROLE_CONF_H_ */
