@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_DISC_H
-#define __PAROLE_DISC_H
+#ifndef SRC_PAROLE_DISC_H_
+#define SRC_PAROLE_DISC_H_
 
 #include <glib-object.h>
 
@@ -33,37 +33,31 @@ G_BEGIN_DECLS
 
 typedef struct ParoleDiscPrivate ParoleDiscPrivate;
 
-typedef enum
-{
+typedef enum {
     PAROLE_DISC_UNKNOWN,
     PAROLE_DISC_CDDA,
     PAROLE_DISC_VCD,
     PAROLE_DISC_SVCD,
     PAROLE_DISC_DVD
-    
 } ParoleDiscKind;
 
-typedef struct
-{
+typedef struct {
     GObject                parent;
     ParoleDiscPrivate     *priv;
-    
 } ParoleDisc;
 
-typedef struct
-{
+typedef struct {
     GObjectClass       parent_class;
-    
+
     void            (*disc_selected)            (ParoleDisc *disc,
                                                  const gchar *uri,
                                                  const gchar *device);
-                            
+
     void            (*label_changed)            (ParoleDisc *disc,
                                                  const gchar *label_changed);
-                                     
+
     void            (*dvd_enabled)              (ParoleDisc *disc,
                                                  gboolean dvd_enabled);
-    
 } ParoleDiscClass;
 
 GType               parole_disc_get_type        (void) G_GNUC_CONST;
@@ -72,4 +66,4 @@ ParoleDisc         *parole_disc_new             (void);
 
 G_END_DECLS
 
-#endif /* __PAROLE_DISC_H */
+#endif /* SRC_PAROLE_DISC_H_ */
