@@ -56,6 +56,8 @@ struct _ParoleProviderModule {
     gboolean                active;
     gpointer                instance;
     gchar                  *desktop_file;
+
+    gulong                  use_count;
 };
 
 struct _ParoleProviderModuleClass {
@@ -74,6 +76,9 @@ void                        parole_provider_module_free_plugin     (ParoleProvid
 
 gboolean                    parole_provider_module_get_is_active   (ParoleProviderModule *module);
 
+gboolean                    parole_provider_module_use             (ParoleProviderModule *module);
+void                        parole_provider_module_unuse           (ParoleProviderModule *module);
+
 G_END_DECLS
 
 #endif /* SRC_PAROLE_MODULE_H_ */
