@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,11 +20,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __PAROLE_PLAYER_H
-#define __PAROLE_PLAYER_H
+#ifndef SRC_PAROLE_PLAYER_H_
+#define SRC_PAROLE_PLAYER_H_
 
 #include <glib-object.h>
-#include "parole-medialist.h"
+
+#include "src/parole-medialist.h"
 
 G_BEGIN_DECLS
 
@@ -34,15 +35,12 @@ G_BEGIN_DECLS
 
 typedef struct ParolePlayerPrivate ParolePlayerPrivate;
 
-typedef struct
-{
+typedef struct {
     GObject                     parent;
     ParolePlayerPrivate        *priv;
-
 } ParolePlayer;
 
-typedef struct
-{
+typedef struct {
     GObjectClass                parent_class;
 
     void                        (*shuffle_toggled)              (ParolePlayer *player,
@@ -53,11 +51,9 @@ typedef struct
 
     void                        (*gst_dvd_nav_message)          (ParolePlayer *player,
                                                                  gint gst_dvd_nav_message);
-
 } ParolePlayerClass;
 
-typedef enum
-{
+typedef enum {
     PAROLE_PLAYER_ACTION_PREVIOUS,
     PAROLE_PLAYER_ACTION_NEXT,
     PAROLE_PLAYER_ACTION_PLAYPAUSE
@@ -84,4 +80,4 @@ GSimpleAction                  *parole_player_get_action(ParolePlayerAction acti
 
 G_END_DECLS
 
-#endif /* __PAROLE_PLAYER_H */
+#endif /* SRC_PAROLE_PLAYER_H_ */
