@@ -95,9 +95,6 @@ static void parole_plugins_manager_set_property(GObject *object,
                                                     const GValue *value,
                                                     GParamSpec *pspec);
 
-#define PAROLE_PLUGINS_MANAGER_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE((o), PAROLE_TYPE_PLUGINS_MANAGER, ParolePluginsManagerPrivate))
-
 struct ParolePluginsManagerPrivate {
     GtkWidget *list_nt;
     GtkWidget *main_window;
@@ -111,7 +108,7 @@ struct ParolePluginsManagerPrivate {
 
 static gpointer parole_plugins_manager_object = NULL;
 
-G_DEFINE_TYPE(ParolePluginsManager, parole_plugins_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE(ParolePluginsManager, parole_plugins_manager, G_TYPE_OBJECT)
 
 enum {
     COL_ACTIVE,
@@ -192,6 +189,7 @@ static void
 parole_plugins_manager_save_rc(ParolePluginsManager *manager, gchar *filename, gboolean active) {
     gchar **saved_plugins;
     gchar **plugins_rc;
+    gchar  *basename;
     guint num = 0, i, count = 0;
 
     saved_plugins = parole_conf_read_entry_list(PAROLE_CONF(manager->priv->conf), "plugins");
@@ -206,17 +204,19 @@ parole_plugins_manager_save_rc(ParolePluginsManager *manager, gchar *filename, g
             plugins_rc[i] = g_strdup(saved_plugins[i]);
         }
 
-        plugins_rc[num] = g_strdup(filename);
+        plugins_rc[num] = g_path_get_basename(filename);
         plugins_rc[num + 1] = NULL;
         parole_conf_write_entry_list(PAROLE_CONF(manager->priv->conf), "plugins", plugins_rc);
     } else {
         plugins_rc = g_new0(gchar *, num + 1);
 
         for (i = 0; i < num; i++) {
-            if ( g_strcmp0(saved_plugins[i], filename) != 0 ) {
+            basename = g_path_get_basename (filename);
+            if ( g_strcmp0(saved_plugins[i], filename) != 0 && g_strcmp0(saved_plugins[i], basename) != 0 ) {
                 plugins_rc[count] = g_strdup(saved_plugins[i]);
                 count++;
             }
+            g_free (basename);
         }
         plugins_rc[num] = NULL;
         parole_conf_write_entry_list(PAROLE_CONF(manager->priv->conf), "plugins", plugins_rc);
@@ -246,19 +246,19 @@ parole_plugins_manager_cell_toggled_cb(GtkCellRendererToggle *cell_renderer,
 
         if ( pref->manager->priv->load_plugins ) {
             if ( active ) {
-                g_type_module_use(G_TYPE_MODULE(module));
+                parole_provider_module_use(module);
                 if (!parole_provider_module_new_plugin(module)) {
                     // If plugin loading fails...
                     parole_dialog_error(GTK_WINDOW(pref->window),
                         _("Plugin failed to load"),
                         _("Please check your installation"));
                     parole_provider_module_free_plugin(module);
-                    g_type_module_unuse(G_TYPE_MODULE(module));
+                    parole_provider_module_unuse(module);
                     active = FALSE;
                 }
             } else {
                 parole_provider_module_free_plugin(module);
-                g_type_module_unuse(G_TYPE_MODULE(module));
+                parole_provider_module_unuse(module);
             }
         }
 
@@ -521,7 +521,7 @@ parole_plugins_manager_load_plugins(ParolePluginsManager *manager) {
             if ( !g_strcmp0 (plugins_rc[i], module->name) ||
                  !g_strcmp0(plugins_rc[i], PAROLE_PROVIDER_MODULE(module)->library_name) ) {
                 TRACE("Loading plugin :%s", module->name);
-                if ( !g_type_module_use(module) ) {
+                if ( !parole_provider_module_use (PAROLE_PROVIDER_MODULE(module)) ) {
                     parole_plugins_manager_save_rc(manager, module->name, FALSE);
                     g_ptr_array_remove(manager->priv->array, module);
                     g_object_unref(module);
@@ -550,15 +550,13 @@ parole_plugins_manager_class_init(ParolePluginsManagerClass *klass) {
                                                               TRUE,
                                                               G_PARAM_CONSTRUCT_ONLY|
                                                               G_PARAM_READWRITE));
-
-    g_type_class_add_private (klass, sizeof (ParolePluginsManagerPrivate));
 }
 
 static void
 parole_plugins_manager_init(ParolePluginsManager *manager) {
     GtkBuilder *builder;
 
-    manager->priv = PAROLE_PLUGINS_MANAGER_GET_PRIVATE(manager);
+    manager->priv = parole_plugins_manager_get_instance_private(manager);
 
     manager->priv->array = g_ptr_array_new();
 
