@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -22,24 +24,21 @@
 #include <config.h>
 #endif
 
-#include <src/misc/parole.h>
+#include "src/misc/parole.h"
 
-#include "sample-provider.h"
+#include "src/plugins/sample/sample-provider.h"
 
-G_MODULE_EXPORT GType	parole_plugin_initialize (ParoleProviderPlugin *plugin);
-						  
-G_MODULE_EXPORT void	parole_plugin_shutdown   (void);
+G_MODULE_EXPORT GType   parole_plugin_initialize(ParoleProviderPlugin *plugin);
+
+G_MODULE_EXPORT void    parole_plugin_shutdown(void);
 
 G_MODULE_EXPORT GType
-parole_plugin_initialize (ParoleProviderPlugin *plugin)
-{
-    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
-    sample_provider_register_type (plugin);
+parole_plugin_initialize(ParoleProviderPlugin *plugin) {
+    xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+    sample_provider_register_type(plugin);
     return SAMPLE_TYPE_PROVIDER;
 }
 
 G_MODULE_EXPORT void
-parole_plugin_shutdown (void)
-{
-    
+parole_plugin_shutdown(void) {
 }
