@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,10 +20,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef SAMPLE_PROVIDER_H_
-#define SAMPLE_PROVIDER_H_
+#ifndef SRC_PLUGINS_SAMPLE_SAMPLE_PROVIDER_H_
+#define SRC_PLUGINS_SAMPLE_SAMPLE_PROVIDER_H_
 
-#include <src/misc/parole.h>
+#include "src/misc/parole.h"
 
 G_BEGIN_DECLS
 
@@ -37,10 +37,10 @@ typedef struct _SampleProvider      SampleProvider;
 #define SAMPLE_IS_PROVIDER_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), SAMPLE_TYPE_PROVIDER))
 #define SAMPLE_PROVIDER_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), SAMPLE_TYPE_PROVIDER, SampleProviderClass))
 
-GType sample_provider_get_type          (void) G_GNUC_CONST G_GNUC_INTERNAL;
+GType sample_provider_get_type           (void) G_GNUC_CONST G_GNUC_INTERNAL;
 
-void  sample_provider_register_type (ParoleProviderPlugin *plugin);
+void  sample_provider_register_type      (ParoleProviderPlugin *plugin);
 
 G_END_DECLS
 
-#endif /*SAMPLE_PROVIDER_H_*/
+#endif /* SRC_PLUGINS_SAMPLE_SAMPLE_PROVIDER_H_ */
