@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
- * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
+ * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -20,10 +20,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef TRAY_PROVIDER_H_
-#define TRAY_PROVIDER_H_
+#ifndef SRC_PLUGINS_TRAY_TRAY_PROVIDER_H_
+#define SRC_PLUGINS_TRAY_TRAY_PROVIDER_H_
 
-#include <src/misc/parole.h>
+#include "src/misc/parole.h"
 
 G_BEGIN_DECLS
 
@@ -43,4 +43,4 @@ void  tray_provider_register_type   (ParoleProviderPlugin *provider);
 
 G_END_DECLS
 
-#endif /*TRAY_PROVIDER_H_*/
+#endif /* SRC_PLUGINS_TRAY_TRAY_PROVIDER_H_ */
